@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 require 'gtk2'
-miquire :lib, 'diva_hacks'
+require 'lib/diva_hacks'
 
 module Pango
   ESCAPE_RULE = {'&': '&amp;'.freeze ,'>': '&gt;'.freeze, '<': '&lt;'.freeze}.freeze
@@ -16,11 +16,13 @@ module Pango
 
     # パースエラーが発生した場合、その文字列をerrorで印字する。
     def parse_markup(str)
-      begin
-        old_parse_markup(str)
-      rescue GLib::Error => e
-        error str
-        raise e end end end end
+      old_parse_markup(str)
+    rescue GLib::Error => e
+      error str
+      raise e
+    end
+  end
+end
 
 =begin rdoc
   本文の、描画するためのテキストを生成するモジュール。
@@ -52,13 +54,11 @@ module Gdk::MarkupGenerator
   end
 
   def clickable?(model)
-    has_model_intent = Enumerator.new {|y| Plugin.filtering(:intent_select_by_model_slug, model.class.slug, y) }.first
+    has_model_intent = Plugin.collect(:intent_select_by_model_slug, model.class.slug, Pluggaloid::COLLECT).first
     return true if has_model_intent
-    Enumerator.new {|y|
-      Plugin.filtering(:model_of_uri, model.uri, y)
-    }.any?{|model_slug|
-      Enumerator.new {|y| Plugin.filtering(:intent_select_by_model_slug, model_slug, y) }.first
-    }
+    Plugin.collect(:model_of_uri, model.uri).any? do |model_slug|
+      Plugin.collect(:intent_select_by_model_slug, model_slug, Pluggaloid::COLLECT).first
+    end
   end
 
   # Entityを適用したあとのプレーンテキストを返す。
@@ -67,8 +67,8 @@ module Gdk::MarkupGenerator
     _plain_description[UserConfig[:miraclepainter_expand_custom_emoji]]
   end
 
-  private memoize def _plain_description
-    Hash.new do |h, expand_emoji|
+  private def _plain_description
+    @_plain_description ||= Hash.new do |h, expand_emoji|
       h[expand_emoji] = score.map{|note|
         if expand_emoji && note.respond_to?(:inline_photo)
           '.'
