@@ -3,18 +3,17 @@
 require 'gtk2'
 require 'cairo'
 
-miquire :mui, 'coordinate_module'
-miquire :mui, 'icon_over_button'
-miquire :mui, 'textselector'
-miquire :mui, 'sub_parts_helper'
-miquire :mui, 'replyviewer'
-miquire :mui, 'sub_parts_favorite'
-miquire :mui, 'sub_parts_share'
-miquire :mui, 'sub_parts_quote'
-miquire :mui, 'markup_generator'
-miquire :mui, 'special_edge'
-miquire :mui, 'photo_pixbuf'
-miquire :lib, 'uithreadonly'
+require 'mui/cairo_coordinate_module'
+require 'mui/cairo_icon_over_button'
+require 'mui/cairo_textselector'
+require 'mui/cairo_sub_parts_helper'
+require 'mui/cairo_replyviewer'
+require 'mui/cairo_sub_parts_favorite'
+require 'mui/cairo_sub_parts_share'
+require 'mui/cairo_sub_parts_quote'
+require 'mui/cairo_markup_generator'
+require 'mui/cairo_special_edge'
+require 'mui/gtk_photo_pixbuf'
 
 # 一つのMessageをPixbufにレンダリングするためのクラス。名前は言いたかっただけ。クラス名まで全てはつね色に染めて♪
 # 情報を設定してから、 Gdk::MiraclePainter#pixbuf で表示用の GdkPixbuf::Pixbuf のインスタンスを得ることができる。
@@ -30,7 +29,6 @@ class Gdk::MiraclePainter < Gtk::Object
   include Gdk::TextSelector
   include Gdk::SubPartsHelper
   include Gdk::MarkupGenerator
-  include UiThreadOnly
 
   EMPTY = Set.new.freeze
   Event = Struct.new(:event, :message, :timeline, :miraclepainter)
@@ -47,8 +45,8 @@ class Gdk::MiraclePainter < Gtk::Object
   deprecate :to_message, :none, 2017, 5
 
   # :nodoc:
-  memoize def score
-    Plugin[:gtk].score_of(message)
+  def score
+    @score ||= Plugin[:gtk].score_of(message)
   end
 
   # @@miracle_painters = Hash.new
@@ -306,7 +304,6 @@ class Gdk::MiraclePainter < Gtk::Object
   # 更新イベントを発生させる
   def on_modify(event=true)
     if not destroyed?
-      @modify_source = caller(1)
       @pixmap = nil
       @pixbuf = nil
       @coordinate = nil
@@ -338,6 +335,12 @@ class Gdk::MiraclePainter < Gtk::Object
     freeze
   end
 
+  @@font_description = Hash.new{|h,k| h[k] = {} } # {scale => {font => FontDescription}}
+  def font_description(font)
+    @@font_description[scale(0xffff)][font] ||=
+      Pango::FontDescription.new(font).tap{|fd| fd.size = scale(fd.size) }
+  end
+
   private
 
   def dummy_context
@@ -372,12 +375,6 @@ class Gdk::MiraclePainter < Gtk::Object
     end
     layout end
 
-  @@font_description = Hash.new{|h,k| h[k] = {} } # {scale => {font => FontDescription}}
-  def font_description(font)
-    @@font_description[scale(0xffff)][font] ||=
-      Pango::FontDescription.new(font).tap{|fd| fd.size = scale(fd.size) }
-  end
-
   # 絵文字を描画する時の一辺の大きさを返す
   # ==== Args
   # [font] font description
@@ -447,6 +444,13 @@ class Gdk::MiraclePainter < Gtk::Object
     pm = Gdk::Pixmap.new(nil, width, height, color)
     render_to_context pm.create_cairo_context
     pm
+  rescue Cairo::InvalidSize => exc
+    error 'Cairo::InvalidSize: width=%{width} height=%{height} message=%{perma_link}' % {
+      width: width,
+      height: height,
+      perma_link: message.perma_link
+    }
+    raise
   end
 
   # pixbufを組み立てる
@@ -567,12 +571,8 @@ class Gdk::MiraclePainter < Gtk::Object
   end
 
   class << self
-    extend Memoist
-
-    memoize def gb_foot
-      Enumerator.new{|y|
-        Plugin.filtering(:photo_filter, Cairo::SpecialEdge::FOOTER_URL, y)
-      }.first
+    def gb_foot
+      @gb_foot ||= Plugin.collect(:photo_filter, Cairo::SpecialEdge::FOOTER_URL, Pluggaloid::COLLECT).first
     end
   end
 
