@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-miquire :mui, 'sub_parts_helper'
+require 'mui/cairo_sub_parts_helper'
 
 require 'gtk2'
 require 'cairo'
