@@ -10,10 +10,10 @@ module Gtk::FormDSL
   PIXBUF_PHOTO_FILTER = Hash[GdkPixbuf::Pixbuf.formats.map{|f| ["#{f.description} (#{f.name})", f.extensions.flat_map{|x| [x.downcase.freeze, x.upcase.freeze] }.freeze] }].freeze
   PHOTO_FILTER = {'All images' => PIXBUF_PHOTO_FILTER.values.flatten}.merge(PIXBUF_PHOTO_FILTER).merge('All files' => ['*'])
 
-  def initialize(*args)
+  def initialize(*args, &block)
     super
-    if block_given?
-      instance_eval(&Proc.new)
+    if block
+      instance_eval(&block)
     end
   end
 
@@ -119,8 +119,12 @@ module Gtk::FormDSL
     container = Gtk::HBox.new(false, 0)
     input = Gtk::Entry.new
     input.text = self[config] || ""
-    container.pack_start(Gtk::Label.new(label), false, true, 0) if label
-    container.pack_start(Gtk::Alignment.new(1.0, 0.5, 0, 0).add(input), true, true, 0)
+    if label
+      container.pack_start(Gtk::Label.new(label), false, true, 0)
+      container.pack_start(Gtk::Alignment.new(1.0, 0.5, 0, 0).add(input), true, true, 0)
+    else
+      container.pack_start(input, true, true, 0)
+    end
     input.signal_connect(:changed){ |widget|
       self[config] = widget.text
       false
@@ -191,14 +195,14 @@ module Gtk::FormDSL
   # ==== Args
   # [title] ラベル
   # [&block] ブロック
-  def settings(title)
+  def settings(title, &block)
     group = Gtk::Frame.new.set_border_width(8)
     if(title.is_a?(Gtk::Widget))
       group.set_label_widget(title)
     else
       group.set_label(title) end
     box = create_inner_setting.set_border_width(4)
-    box.instance_eval(&Proc.new)
+    box.instance_eval(&block)
     closeup group.add(box)
     group
   end
@@ -215,9 +219,9 @@ module Gtk::FormDSL
   #   _:license_ :: ライセンス
   #   _:website_ :: Webページ
   #   _:logo_ :: ロゴ画像。 フルパス(String)か、Photo Modelか、GdkPixbuf::Pixbufを指定する
-  #   _:authors_ :: 作者の名前。通常Twitter screen name（Array）
-  #   _:artists_ :: デザイナとかの名前。通常Twitter screen name（Array）
-  #   _:documenters_ :: ドキュメントかいた人とかの名前。通常Twitter screen name（Array）
+  #   _:authors_ :: 作者の名前。通常MastodonのAcct（Array）
+  #   _:artists_ :: デザイナとかの名前。通常MastodonのAcct（Array）
+  #   _:documenters_ :: ドキュメントかいた人とかの名前。通常MastodonのAcct（Array）
   def about(label, options={})
     name_mapper = Hash.new{|h,k| k }
     name_mapper[:name] = :program_name
@@ -264,6 +268,30 @@ module Gtk::FormDSL
     container
   end
 
+  # リストビューを表示する。
+  # ==== Args
+  # [config] 設定のキー
+  # [columns:]
+  #   配列の配列で、各要素は[カラムのタイトル(String), カラムの表示文字を返すProc]
+  # [reorder:]
+  #   _true_ なら、ドラッグ＆ドロップによる並び替えを許可する
+  # [&block] 内容
+  def listview(config, columns:, edit: true, reorder: edit, object_initializer: :itself.to_proc, &generate)
+    listview = Gtk::FormDSL::ListView.new(
+      self, columns, config, object_initializer,
+      create: edit,
+      update: edit,
+      delete: edit,
+      reorder: reorder,
+      &generate)
+    pack_start(Gtk::VBox.new(false, 4).
+                 #closeup(listview.filter_entry).
+                 add(Gtk::HBox.new(false, 4).
+                       add(listview)
+                       .closeup(listview.buttons(Gtk::VBox))
+                    ))
+  end
+
   # 要素を１つ選択させる
   # ==== Args
   # [label] ラベル
@@ -272,9 +300,9 @@ module Gtk::FormDSL
   #   連想配列で、 _値_ => _ラベル_ の形式で、デフォルト値を与える。
   #   _block_ と同時に与えれられたら、 _default_ の値が先に入って、 _block_ は後に入る。
   # [&block] 内容
-  def select(label, config, default = {})
-    builder = Gtk::FormDSL::Select.new(self, default)
-    builder.instance_eval(&Proc.new) if block_given?
+  def select(label, config, default = {}, mode: :auto, **kwrest, &block)
+    builder = Gtk::FormDSL::Select.new(self, default.merge(kwrest), mode: mode)
+    builder.instance_eval(&block) if block
     closeup container = builder.build(label, config)
     container
   end
@@ -287,13 +315,23 @@ module Gtk::FormDSL
   #   連想配列で、 _値_ => _ラベル_ の形式で、デフォルト値を与える。
   #   _block_ と同時に与えれられたら、 _default_ の値が先に入って、 _block_ は後に入る。
   # [&block] 内容
-  def multiselect(label, config, default = {})
-    builder = Gtk::FormDSL::MultiSelect.new(self, default)
-    builder.instance_eval(&Proc.new) if block_given?
+  def multiselect(label, config, default = {}, mode: :auto, &block)
+    builder = Gtk::FormDSL::MultiSelect.new(self, default, mode: mode)
+    builder.instance_eval(&block) if block
     closeup container = builder.build(label, config)
     container
   end
 
+  def keybind(title, config)
+    keyconfig = Gtk::KeyConfig.new(title, self[config] || "")
+    container = Gtk::HBox.new(false, 0)
+    container.pack_start(Gtk::Label.new(title), false, true, 0)
+    container.pack_start(Gtk::Alignment.new(1.0, 0.5, 0, 0).add(keyconfig), true, true, 0)
+    keyconfig.change_hook = ->(modify) { self[config] = modify }
+    closeup(container)
+    container
+  end
+
   # 引数のテキストを表示する。
   def label(text)
     label = Gtk::Label.new(text, false)
@@ -362,9 +400,7 @@ module Gtk::FormDSL
         when Diva::Model
           value.pixbuf(width: 48, height: 48)
         else
-          Enumerator.new{ |y|
-            Plugin.filtering(:photo_filter, value, y)
-          }.first.pixbuf(width: 48, height: 48) rescue nil
+          Plugin.collect(:photo_filter, value, Pluggaloid::COLLECT).first.pixbuf(width: 48, height: 48) rescue nil
         end
       }
     )
@@ -451,7 +487,7 @@ module Gtk::FormDSL
   end
 
   def fs_photo_thumbnail(path)
-    Enumerator.new{|y| Plugin.filtering(:photo_filter, path, y) }.first
+    Plugin.collect(:photo_filter, path, Pluggaloid::COLLECT).first
   end
 
   def gen_fileselect_dialog_generator(title, action, dir, config:, shortcuts: [], filters: {}, use_preview: false, &result_callback)
@@ -475,27 +511,23 @@ module Gtk::FormDSL
 
       shortcuts.select { |dir|
         !dialog.shortcut_folders.include?(dir)
-      }.each { |dir|
-        begin
-          dialog.add_shortcut_folder(dir)
-        rescue => e
-          puts e
-          puts e.backtrace
-        end
-      }
+      }.each do |dir|
+        dialog.add_shortcut_folder(dir)
+      rescue => e
+        puts e
+        puts e.backtrace
+      end
 
       if use_preview
         preview = Gtk::Image.new
         dialog.preview_widget = preview
-        dialog.signal_connect("update-preview") do
-          begin
-            path = dialog.preview_filename
-            pixbuf = Gdk::Pixbuf.new(file: path, width: 256, height: 256)
-            preview.set_pixbuf(pixbuf)
-            dialog.set_preview_widget_active(true)
-          rescue => e
-            dialog.set_preview_widget_active(false)
-          end
+        dialog.ssc(:update_preview) do
+          path = dialog.preview_filename
+          pixbuf = Gdk::Pixbuf.new(file: path, width: 256, height: 256)
+          preview.set_pixbuf(pixbuf)
+          dialog.set_preview_widget_active(true)
+        rescue => e
+          dialog.set_preview_widget_active(false)
         end
       end
 
@@ -524,4 +556,6 @@ module Gtk::FormDSL
   end
 end
 
-miquire :mui, 'form_dsl_select', 'form_dsl_multi_select'
+require 'mui/gtk_form_dsl_select'
+require 'mui/gtk_form_dsl_multi_select'
+require 'mui/gtk_form_dsl_listview'
