@@ -1,20 +1,30 @@
 # -*- coding: utf-8 -*-
-miquire :mui, 'form_dsl'
+require 'mui/gtk_form_dsl'
 
 class Gtk::FormDSL::Select
-  def initialize(parent_dslobj, values = [])
+  def initialize(parent_dslobj, values = [], mode: :auto)
     @parent_dslobj = parent_dslobj
-    @options = values.to_a.freeze end
+    @options = values.to_a.freeze
+    @mode = mode
+  end
+
+  def mode
+    if @mode == :auto
+      has_widget? ? :radio : :combo
+    else
+      @mode
+    end
+  end
 
   # セレクトボックスに要素を追加する
   # ==== Args
   # [value] 選択されたらセットされる値
   # [label] ラベル。 _&block_ がなければ使われる。文字列。
   # [&block] Plugin::Settings のインスタンス内で評価され、そのインスタンスが内容として使われる
-  def option(value, label = nil)
-    if block_given?
+  def option(value, label = nil, &block)
+    if block
       widget = @parent_dslobj.create_inner_setting.set_border_width(4)
-      widget.instance_eval(&Proc.new)
+      widget.instance_eval(&block)
       @options += [[value, label, widget].freeze]
     else
       @options += [[value, label].freeze]
@@ -37,12 +47,13 @@ class Gtk::FormDSL::Select
   # ==== Return
   # ウィジェット
   def build(label, config_key)
-    if has_widget?
+    case mode
+    when :radio
       group = Gtk::Frame.new.set_border_width(8)
       group.set_label(label)
       group.add(build_box(config_key))
       group
-    else
+    when :combo
       Gtk::HBox.new(false, 0).add(Gtk::Label.new(label).left).closeup(build_combobox(config_key))
     end
   end
