@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 require 'gtk2'
-miquire :mui, 'extension'
+require 'mui/gtk_extension'
 
 class Gtk::InnerUserList < Gtk::TreeView
   include Gtk::TreeViewPrettyScroll
@@ -32,10 +32,10 @@ class Gtk::InnerUserList < Gtk::TreeView
     }.reject{|user|
       exist_users.include?(user)
     }.deach{|user|
+      break if destroyed?
       iter = model.append
-      iter[COL_ICON] = user.icon.load_pixbuf(width: 24, height: 24){|pixbuf|
-        iter[COL_ICON] = pixbuf unless destroyed?
-      }
+      # ここではCOL_ICONを埋めず、nilのままにしてアイコンを表示しない。
+      # アイコンは Gtk::UserList#emit_expose_user で、カラムが表示された時に初めて埋める
       iter[COL_SCREEN_NAME] = user[:idname]
       iter[COL_NAME] = user[:name]
       iter[COL_USER] = user
